# ref: https://learn.microsoft.com/en-us/defender-xdr/malware-naming?view=o365-worldwide
from collections import defaultdict

PLATFORM = defaultdict(lambda: "")
PLATFORM['AndroidOS'] = "Android operating system"
PLATFORM['DOS'] = "MS-DOS platform"
PLATFORM['EPOC'] = "Psion devices"
PLATFORM['FreeBSD'] = "FreeBSD platform"
PLATFORM['iOS'] = "iPhone operating system"
PLATFORM['Linux'] = "Linux platform"
PLATFORM['macOS'] = "MAC 9.x platform or earlier"
PLATFORM['macOS_X'] = "macOS X or later"
PLATFORM['OS2'] = "OS2 platform"
PLATFORM['Palm'] = "Palm operating system"
PLATFORM['Solaris'] = "System V-based Unix platforms"
PLATFORM['SunOS'] = "Unix platforms 4.1.3 or lower"
PLATFORM['SymbOS'] = "Symbian operating system"
PLATFORM['Unix'] = "general Unix platforms"
PLATFORM['Win16'] = "Win16 (3.1) platform"
PLATFORM['Win2K'] = "Windows 2000 platform"
PLATFORM['Win32'] = "Windows 32-bit platform"
PLATFORM['Win64'] = "Windows 64-bit platform"
PLATFORM['Win95'] = "Windows 95, 98 and ME platforms"
PLATFORM['Win98'] = "Windows 98 platform only"
PLATFORM['WinCE'] = "Windows CE platform"
PLATFORM['WinNT'] = "WinNT"
PLATFORM['ABAP'] = "Advanced Business Application Programming scripts"
PLATFORM['ALisp'] = "ALisp scripts"
PLATFORM['AmiPro'] = "AmiPro script"
PLATFORM['ANSI'] = "American National Standards Institute scripts"
PLATFORM['AppleScript'] = "compiled Apple scripts"
PLATFORM['ASP'] = "Active Server Pages scripts"
PLATFORM['AutoIt'] = "AutoIT scripts"
PLATFORM['BAS'] = "Basic scripts"
PLATFORM['BAT'] = "Basic scripts"
PLATFORM['CorelScript'] = "Corelscript scripts"
PLATFORM['HTA'] = "HTML Application scripts"
PLATFORM['HTML'] = "HTML Application scripts"
PLATFORM['INF'] = "Install scripts"
PLATFORM['IRC'] = "mIRC/pIRC scripts"
PLATFORM['Java'] = "Java binaries (classes)"
PLATFORM['JS'] = "JavaScript scripts"
PLATFORM['LOGO'] = "LOGO scripts"
PLATFORM['MPB'] = "MapBasic scripts"
PLATFORM['MSH'] = "Monad shell scripts"
PLATFORM['MSIL'] = ".NET intermediate language scripts"
PLATFORM['Perl'] = "Perl scripts"
PLATFORM['PHP'] = "Hypertext Preprocessor scripts"
PLATFORM['Python'] = "Python scripts"
PLATFORM['SAP'] = "SAP platform scripts"
PLATFORM['SH'] = "Shell scripts"
PLATFORM['VBA'] = "Visual Basic for Applications scripts"
PLATFORM['VBS'] = "Visual Basic scripts"
PLATFORM['WinBAT'] = "Winbatch scripts"
PLATFORM['WinHlp'] = "Windows Help scripts"
PLATFORM['WinREG'] = "Windows registry scripts"
PLATFORM['A97M'] = "Access 97, 2000, XP, 2003, 2007, and 2010 macros"
PLATFORM['HE'] = "macro scripting"
PLATFORM['O97M'] = "Office 97, 2000, XP, 2003, 2007, and 2010 macros - those that affect Word, Excel, and PowerPoint"
PLATFORM['PP97M'] = "PowerPoint 97, 2000, XP, 2003, 2007, and 2010 macros"
PLATFORM['V5M'] = "Visio5 macros"
PLATFORM['W1M'] = "Word1Macro"
PLATFORM['W2M'] = "Word2Macro"
PLATFORM['W97M'] = "Word 97, 2000, XP, 2003, 2007, and 2010 macros"
PLATFORM['WM'] = "Word 95 macros"
PLATFORM['X97M'] = "Excel 97, 2000, XP, 2003, 2007, and 2010 macros"
PLATFORM['XF'] = "Excel formulas"
PLATFORM['XM'] = "Excel 95 macros"
PLATFORM['ASX'] = "XML metafile of Windows Media .asf files"
PLATFORM['HC'] = "HyperCard Apple scripts"
PLATFORM['MIME'] = "MIME packets"
PLATFORM['Netware'] = "Novell Netware files"
PLATFORM['QT'] = "Quicktime files"
PLATFORM['SB'] = "StarBasic (StarOffice XML) files"
PLATFORM['SWF'] = "Shockwave Flash files"
PLATFORM['TSQL'] = "MS SQL server files"
PLATFORM['XML'] = "XML files"