from collections import defaultdict

THREAT_NAME_PREFIX = defaultdict(lambda:"")
THREAT_NAME_PREFIX[0x0185] = "Backdoor:BAT/"
THREAT_NAME_PREFIX[0x0186] = "Backdoor:FreeBSD/"
THREAT_NAME_PREFIX[0x0187] = "Backdoor:MSIL/"
THREAT_NAME_PREFIX[0x0189] = "TrojanDownloader:BAT/"
THREAT_NAME_PREFIX[0x018a] = "TrojanDownloader:FreeBSD/"
THREAT_NAME_PREFIX[0x018b] = "TrojanDownloader:MSIL/"
THREAT_NAME_PREFIX[0x018d] = "TrojanDropper:BAT/"
THREAT_NAME_PREFIX[0x018e] = "TrojanDropper:FreeBSD/"
THREAT_NAME_PREFIX[0x018f] = "TrojanDropper:MSIL/"
THREAT_NAME_PREFIX[0x0191] = "Spammer:BAT/"
THREAT_NAME_PREFIX[0x0192] = "Spammer:FreeBSD/"
THREAT_NAME_PREFIX[0x0193] = "Spammer:MSIL/"
THREAT_NAME_PREFIX[0x0195] = "DDoS:BAT/"
THREAT_NAME_PREFIX[0x0196] = "DDoS:FreeBSD/"
THREAT_NAME_PREFIX[0x0197] = "DDoS:MSIL/"
THREAT_NAME_PREFIX[0x0199] = "DoS:BAT/"
THREAT_NAME_PREFIX[0x019a] = "DoS:FreeBSD/"
THREAT_NAME_PREFIX[0x019b] = "DoS:MSIL/"
THREAT_NAME_PREFIX[0x019d] = "Joke:BAT/"
THREAT_NAME_PREFIX[0x019e] = "Joke:FreeBSD/"
THREAT_NAME_PREFIX[0x019f] = "Joke:MSIL/"
THREAT_NAME_PREFIX[0x01a1] = "PWS:BAT/"
THREAT_NAME_PREFIX[0x01a2] = "PWS:FreeBSD/"
THREAT_NAME_PREFIX[0x01a3] = "PWS:MSIL/"
THREAT_NAME_PREFIX[0x01a5] = "Worm:BAT/"
THREAT_NAME_PREFIX[0x01a6] = "Worm:FreeBSD/"
THREAT_NAME_PREFIX[0x01a7] = "Worm:MSIL/"
THREAT_NAME_PREFIX[0x01aa] = "Flooder:FreeBSD/"
THREAT_NAME_PREFIX[0x01ad] = "Trojan:BAT/"
THREAT_NAME_PREFIX[0x01ae] = "Trojan:FreeBSD/"
THREAT_NAME_PREFIX[0x01af] = "Trojan:MSIL/"
THREAT_NAME_PREFIX[0x01b1] = "Virus:BAT/"
THREAT_NAME_PREFIX[0x01b2] = "Virus:FreeBSD/"
THREAT_NAME_PREFIX[0x01b3] = "Virus:MSIL/"
THREAT_NAME_PREFIX[0x01b5] = "Constructor:BAT/"
THREAT_NAME_PREFIX[0x01b6] = "Constructor:FreeBSD/"
THREAT_NAME_PREFIX[0x01b7] = "Constructor:MSIL/"
THREAT_NAME_PREFIX[0x01ba] = "Nuker:FreeBSD/"
THREAT_NAME_PREFIX[0x01be] = "Spoofer:FreeBSD/"
THREAT_NAME_PREFIX[0x01c9] = "TrojanSpy:BAT/"
THREAT_NAME_PREFIX[0x01ca] = "TrojanSpy:FreeBSD/"
THREAT_NAME_PREFIX[0x01cb] = "TrojanSpy:MSIL/"
THREAT_NAME_PREFIX[0x01cd] = "VirTool:BAT/"
THREAT_NAME_PREFIX[0x01ce] = "VirTool:FreeBSD/"
THREAT_NAME_PREFIX[0x01cf] = "VirTool:MSIL/"
THREAT_NAME_PREFIX[0x01d1] = "Exploit:BAT/"
THREAT_NAME_PREFIX[0x01d2] = "Exploit:FreeBSD/"
THREAT_NAME_PREFIX[0x01d3] = "Exploit:MSIL/"
THREAT_NAME_PREFIX[0x01d5] = "TrojanClicker:BAT/"
THREAT_NAME_PREFIX[0x01d6] = "TrojanClicker:FreeBSD/"
THREAT_NAME_PREFIX[0x01d7] = "TrojanClicker:MSIL/"
THREAT_NAME_PREFIX[0x01d9] = "HackTool:BAT/"
THREAT_NAME_PREFIX[0x01da] = "HackTool:FreeBSD/"
THREAT_NAME_PREFIX[0x01db] = "HackTool:MSIL/"
THREAT_NAME_PREFIX[0x01dd] = "TrojanProxy:BAT/"
THREAT_NAME_PREFIX[0x01de] = "TrojanProxy:FreeBSD/"
THREAT_NAME_PREFIX[0x01df] = "TrojanProxy:MSIL/"
THREAT_NAME_PREFIX[0x01ea] = "TrojanNotifier:FreeBSD/"
THREAT_NAME_PREFIX[0x03a5] = "Worm:BAT/"
THREAT_NAME_PREFIX[0x03ad] = "Trojan:BAT/"
THREAT_NAME_PREFIX[0x03b1] = "Virus:BAT/"
THREAT_NAME_PREFIX[0x09a5] = "Worm:BAT/"
THREAT_NAME_PREFIX[0x09a7] = "Worm:MSIL/"
THREAT_NAME_PREFIX[0x09b1] = "Virus:BAT/"
THREAT_NAME_PREFIX[0x1187] = "Backdoor:MSIL/"
THREAT_NAME_PREFIX[0x1189] = "TrojanDownloader:BAT/"
THREAT_NAME_PREFIX[0x118f] = "TrojanDropper:MSIL/"
THREAT_NAME_PREFIX[0x11ad] = "Trojan:BAT/"
THREAT_NAME_PREFIX[0x11b1] = "Virus:BAT/"
THREAT_NAME_PREFIX[0x11cf] = "VirTool:MSIL/"
THREAT_NAME_PREFIX[0x2184] = "Backdoor:Win32/"
THREAT_NAME_PREFIX[0x2185] = "Backdoor:VBS/"
THREAT_NAME_PREFIX[0x2186] = "Backdoor:OS2/"
THREAT_NAME_PREFIX[0x2187] = "Backdoor:INF/"
THREAT_NAME_PREFIX[0x2188] = "TrojanDownloader:Win32/"
THREAT_NAME_PREFIX[0x2189] = "TrojanDownloader:VBS/"
THREAT_NAME_PREFIX[0x218c] = "TrojanDropper:Win32/"
THREAT_NAME_PREFIX[0x218d] = "TrojanDropper:VBS/"
THREAT_NAME_PREFIX[0x2190] = "Spammer:Win32/"
THREAT_NAME_PREFIX[0x2191] = "Spammer:VBS/"
THREAT_NAME_PREFIX[0x2194] = "DDoS:Win32/"
THREAT_NAME_PREFIX[0x2195] = "DDoS:VBS/"
THREAT_NAME_PREFIX[0x2198] = "DoS:Win32/"
THREAT_NAME_PREFIX[0x219c] = "Joke:Win32/"
THREAT_NAME_PREFIX[0x219d] = "Joke:VBS/"
THREAT_NAME_PREFIX[0x219f] = "Joke:INF/"
THREAT_NAME_PREFIX[0x21a0] = "PWS:Win32/"
THREAT_NAME_PREFIX[0x21a1] = "PWS:VBS/"
THREAT_NAME_PREFIX[0x21a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x21a5] = "Worm:VBS/"
THREAT_NAME_PREFIX[0x21a7] = "Worm:INF/"
THREAT_NAME_PREFIX[0x21a8] = "Flooder:Win32/"
THREAT_NAME_PREFIX[0x21ac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x21ad] = "Trojan:VBS/"
THREAT_NAME_PREFIX[0x21ae] = "Trojan:OS2/"
THREAT_NAME_PREFIX[0x21af] = "Trojan:INF/"
THREAT_NAME_PREFIX[0x21b0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x21b1] = "Virus:VBS/"
THREAT_NAME_PREFIX[0x21b2] = "Virus:OS2/"
THREAT_NAME_PREFIX[0x21b3] = "Virus:INF/"
THREAT_NAME_PREFIX[0x21b4] = "Constructor:Win32/"
THREAT_NAME_PREFIX[0x21b5] = "Constructor:VBS/"
THREAT_NAME_PREFIX[0x21b8] = "Nuker:Win32/"
THREAT_NAME_PREFIX[0x21bc] = "Spoofer:Win32/"
THREAT_NAME_PREFIX[0x21c0] = "Tool:Win32/"
THREAT_NAME_PREFIX[0x21c8] = "TrojanSpy:Win32/"
THREAT_NAME_PREFIX[0x21c9] = "TrojanSpy:VBS/"
THREAT_NAME_PREFIX[0x21cc] = "VirTool:Win32/"
THREAT_NAME_PREFIX[0x21cd] = "VirTool:VBS/"
THREAT_NAME_PREFIX[0x21cf] = "VirTool:INF/"
THREAT_NAME_PREFIX[0x21d0] = "Exploit:Win32/"
THREAT_NAME_PREFIX[0x21d1] = "Exploit:VBS/"
THREAT_NAME_PREFIX[0x21d3] = "Exploit:INF/"
THREAT_NAME_PREFIX[0x21d4] = "TrojanClicker:Win32/"
THREAT_NAME_PREFIX[0x21d5] = "TrojanClicker:VBS/"
THREAT_NAME_PREFIX[0x21d8] = "HackTool:Win32/"
THREAT_NAME_PREFIX[0x21d9] = "HackTool:VBS/"
THREAT_NAME_PREFIX[0x21dc] = "TrojanProxy:Win32/"
THREAT_NAME_PREFIX[0x21dd] = "TrojanProxy:VBS/"
THREAT_NAME_PREFIX[0x21e8] = "TrojanNotifier:Win32/"
THREAT_NAME_PREFIX[0x2384] = "Backdoor:Win32/"
THREAT_NAME_PREFIX[0x2388] = "TrojanDownloader:Win32/"
THREAT_NAME_PREFIX[0x238c] = "TrojanDropper:Win32/"
THREAT_NAME_PREFIX[0x238d] = "TrojanDropper:VBS/"
THREAT_NAME_PREFIX[0x2390] = "Spammer:Win32/"
THREAT_NAME_PREFIX[0x2394] = "DDoS:Win32/"
THREAT_NAME_PREFIX[0x239c] = "Joke:Win32/"
THREAT_NAME_PREFIX[0x23a0] = "PWS:Win32/"
THREAT_NAME_PREFIX[0x23a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x23a5] = "Worm:VBS/"
THREAT_NAME_PREFIX[0x23ac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x23b0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x23b1] = "Virus:VBS/"
THREAT_NAME_PREFIX[0x23c8] = "TrojanSpy:Win32/"
THREAT_NAME_PREFIX[0x23cc] = "VirTool:Win32/"
THREAT_NAME_PREFIX[0x23d4] = "TrojanClicker:Win32/"
THREAT_NAME_PREFIX[0x23d8] = "HackTool:Win32/"
THREAT_NAME_PREFIX[0x23dc] = "TrojanProxy:Win32/"
THREAT_NAME_PREFIX[0x2584] = "Backdoor:Win32/"
THREAT_NAME_PREFIX[0x25a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x25a5] = "Worm:VBS/"
THREAT_NAME_PREFIX[0x25ac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x25b0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x25b1] = "Virus:VBS/"
THREAT_NAME_PREFIX[0x2788] = "TrojanDownloader:Win32/"
THREAT_NAME_PREFIX[0x27a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x27ac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x27b0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x29a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x29a5] = "Worm:VBS/"
THREAT_NAME_PREFIX[0x29b0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x29b1] = "Virus:VBS/"
THREAT_NAME_PREFIX[0x2b84] = "Backdoor:Win32/"
THREAT_NAME_PREFIX[0x2b88] = "TrojanDownloader:Win32/"
THREAT_NAME_PREFIX[0x2b8c] = "TrojanDropper:Win32/"
THREAT_NAME_PREFIX[0x2b90] = "Spammer:Win32/"
THREAT_NAME_PREFIX[0x2b98] = "DoS:Win32/"
THREAT_NAME_PREFIX[0x2ba0] = "PWS:Win32/"
THREAT_NAME_PREFIX[0x2ba4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x2ba5] = "Worm:VBS/"
THREAT_NAME_PREFIX[0x2bac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x2bb0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x2bb1] = "Virus:VBS/"
THREAT_NAME_PREFIX[0x2bc8] = "TrojanSpy:Win32/"
THREAT_NAME_PREFIX[0x2bcc] = "VirTool:Win32/"
THREAT_NAME_PREFIX[0x2bd0] = "Exploit:Win32/"
THREAT_NAME_PREFIX[0x2bdc] = "TrojanProxy:Win32/"
THREAT_NAME_PREFIX[0x2d84] = "Backdoor:Win32/"
THREAT_NAME_PREFIX[0x2da4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x2dac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x2dcc] = "VirTool:Win32/"
THREAT_NAME_PREFIX[0x2fac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x2fb0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x3184] = "Backdoor:Win32/"
THREAT_NAME_PREFIX[0x3185] = "Backdoor:VBS/"
THREAT_NAME_PREFIX[0x3188] = "TrojanDownloader:Win32/"
THREAT_NAME_PREFIX[0x3189] = "TrojanDownloader:VBS/"
THREAT_NAME_PREFIX[0x318c] = "TrojanDropper:Win32/"
THREAT_NAME_PREFIX[0x318d] = "TrojanDropper:VBS/"
THREAT_NAME_PREFIX[0x3190] = "Spammer:Win32/"
THREAT_NAME_PREFIX[0x31a0] = "PWS:Win32/"
THREAT_NAME_PREFIX[0x31a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x31a5] = "Worm:VBS/"
THREAT_NAME_PREFIX[0x31a7] = "Worm:INF/"
THREAT_NAME_PREFIX[0x31ac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x31ad] = "Trojan:VBS/"
THREAT_NAME_PREFIX[0x31b0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x31b1] = "Virus:VBS/"
THREAT_NAME_PREFIX[0x31b5] = "Constructor:VBS/"
THREAT_NAME_PREFIX[0x31c8] = "TrojanSpy:Win32/"
THREAT_NAME_PREFIX[0x31cc] = "VirTool:Win32/"
THREAT_NAME_PREFIX[0x31cf] = "VirTool:INF/"
THREAT_NAME_PREFIX[0x31d0] = "Exploit:Win32/"
THREAT_NAME_PREFIX[0x31d1] = "Exploit:VBS/"
THREAT_NAME_PREFIX[0x31d4] = "TrojanClicker:Win32/"
THREAT_NAME_PREFIX[0x31d8] = "HackTool:Win32/"
THREAT_NAME_PREFIX[0x31dc] = "TrojanProxy:Win32/"
THREAT_NAME_PREFIX[0x33a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x3584] = "Backdoor:Win32/"
THREAT_NAME_PREFIX[0x3588] = "TrojanDownloader:Win32/"
THREAT_NAME_PREFIX[0x358c] = "TrojanDropper:Win32/"
THREAT_NAME_PREFIX[0x3590] = "Spammer:Win32/"
THREAT_NAME_PREFIX[0x35a0] = "PWS:Win32/"
THREAT_NAME_PREFIX[0x35a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x35ac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x35b0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x35b4] = "Constructor:Win32/"
THREAT_NAME_PREFIX[0x35c8] = "TrojanSpy:Win32/"
THREAT_NAME_PREFIX[0x35cc] = "VirTool:Win32/"
THREAT_NAME_PREFIX[0x35d4] = "TrojanClicker:Win32/"
THREAT_NAME_PREFIX[0x35d8] = "HackTool:Win32/"
THREAT_NAME_PREFIX[0x35dc] = "TrojanProxy:Win32/"
THREAT_NAME_PREFIX[0x37a4] = "Worm:Win32/"
THREAT_NAME_PREFIX[0x37a5] = "Worm:VBS/"
THREAT_NAME_PREFIX[0x37b0] = "Virus:Win32/"
THREAT_NAME_PREFIX[0x37b1] = "Virus:VBS/"
THREAT_NAME_PREFIX[0x39a0] = "PWS:Win32/"
THREAT_NAME_PREFIX[0x3b84] = "Backdoor:Win32/"
THREAT_NAME_PREFIX[0x3bac] = "Trojan:Win32/"
THREAT_NAME_PREFIX[0x4184] = "Backdoor:Win95/"
THREAT_NAME_PREFIX[0x4185] = "Backdoor:JS/"
THREAT_NAME_PREFIX[0x4189] = "TrojanDownloader:JS/"
THREAT_NAME_PREFIX[0x418d] = "TrojanDropper:JS/"
THREAT_NAME_PREFIX[0x4191] = "Spammer:JS/"
THREAT_NAME_PREFIX[0x4199] = "DoS:JS/"
THREAT_NAME_PREFIX[0x419d] = "Joke:JS/"
THREAT_NAME_PREFIX[0x41a0] = "PWS:Win95/"
THREAT_NAME_PREFIX[0x41a1] = "PWS:JS/"
THREAT_NAME_PREFIX[0x41a4] = "Worm:Win95/"
THREAT_NAME_PREFIX[0x41a5] = "Worm:JS/"
THREAT_NAME_PREFIX[0x41ac] = "Trojan:Win95/"
THREAT_NAME_PREFIX[0x41ad] = "Trojan:JS/"
THREAT_NAME_PREFIX[0x41ae] = "Trojan:Win98/"
THREAT_NAME_PREFIX[0x41af] = "Trojan:SunOS/"
THREAT_NAME_PREFIX[0x41b0] = "Virus:Win95/"
THREAT_NAME_PREFIX[0x41b1] = "Virus:JS/"
THREAT_NAME_PREFIX[0x41b5] = "Constructor:JS/"
THREAT_NAME_PREFIX[0x41c9] = "TrojanSpy:JS/"
THREAT_NAME_PREFIX[0x41cc] = "VirTool:Win95/"
THREAT_NAME_PREFIX[0x41cd] = "VirTool:JS/"
THREAT_NAME_PREFIX[0x41d1] = "Exploit:JS/"
THREAT_NAME_PREFIX[0x41d3] = "Exploit:SunOS/"
THREAT_NAME_PREFIX[0x41d5] = "TrojanClicker:JS/"
THREAT_NAME_PREFIX[0x41d9] = "HackTool:JS/"
THREAT_NAME_PREFIX[0x41dd] = "TrojanProxy:JS/"
THREAT_NAME_PREFIX[0x41df] = "TrojanProxy:SunOS/"
THREAT_NAME_PREFIX[0x43a5] = "Worm:JS/"
THREAT_NAME_PREFIX[0x43ad] = "Trojan:JS/"
THREAT_NAME_PREFIX[0x43b0] = "Virus:Win95/"
THREAT_NAME_PREFIX[0x43b1] = "Virus:JS/"
THREAT_NAME_PREFIX[0x45a5] = "Worm:JS/"
THREAT_NAME_PREFIX[0x45b0] = "Virus:Win95/"
THREAT_NAME_PREFIX[0x47b0] = "Virus:Win95/"
THREAT_NAME_PREFIX[0x49a5] = "Worm:JS/"
THREAT_NAME_PREFIX[0x49ad] = "Trojan:JS/"
THREAT_NAME_PREFIX[0x49b0] = "Virus:Win95/"
THREAT_NAME_PREFIX[0x4b8d] = "TrojanDropper:JS/"
THREAT_NAME_PREFIX[0x4bb0] = "Virus:Win95/"
THREAT_NAME_PREFIX[0x4bb1] = "Virus:JS/"
THREAT_NAME_PREFIX[0x4db0] = "Virus:Win95/"
THREAT_NAME_PREFIX[0x5189] = "TrojanDownloader:JS/"
THREAT_NAME_PREFIX[0x5199] = "DoS:JS/"
THREAT_NAME_PREFIX[0x51ad] = "Trojan:JS/"
THREAT_NAME_PREFIX[0x51b0] = "Virus:Win95/"
THREAT_NAME_PREFIX[0x51d1] = "Exploit:JS/"
THREAT_NAME_PREFIX[0x55a0] = "PWS:Win95/"
THREAT_NAME_PREFIX[0x57ad] = "Trojan:JS/"
THREAT_NAME_PREFIX[0x6184] = "Backdoor:WinNT/"
THREAT_NAME_PREFIX[0x6185] = "Backdoor:Java/"
THREAT_NAME_PREFIX[0x6186] = "Backdoor:Win2K/"
THREAT_NAME_PREFIX[0x6188] = "TrojanDownloader:WinNT/"
THREAT_NAME_PREFIX[0x6189] = "TrojanDownloader:Java/"
THREAT_NAME_PREFIX[0x618c] = "TrojanDropper:WinNT/"
THREAT_NAME_PREFIX[0x618d] = "TrojanDropper:Java/"
THREAT_NAME_PREFIX[0x6190] = "Spammer:WinNT/"
THREAT_NAME_PREFIX[0x6191] = "Spammer:Java/"
THREAT_NAME_PREFIX[0x6199] = "DoS:Java/"
THREAT_NAME_PREFIX[0x619d] = "Joke:Java/"
THREAT_NAME_PREFIX[0x61a0] = "PWS:WinNT/"
THREAT_NAME_PREFIX[0x61a1] = "PWS:Java/"
THREAT_NAME_PREFIX[0x61a4] = "Worm:WinNT/"
THREAT_NAME_PREFIX[0x61a5] = "Worm:Java/"
THREAT_NAME_PREFIX[0x61a6] = "Worm:Win2K/"
THREAT_NAME_PREFIX[0x61a9] = "Flooder:Java/"
THREAT_NAME_PREFIX[0x61ac] = "Trojan:WinNT/"
THREAT_NAME_PREFIX[0x61ad] = "Trojan:Java/"
THREAT_NAME_PREFIX[0x61ae] = "Trojan:Win2K/"
THREAT_NAME_PREFIX[0x61af] = "Trojan:Netware/"
THREAT_NAME_PREFIX[0x61b0] = "Virus:WinNT/"
THREAT_NAME_PREFIX[0x61b1] = "Virus:Java/"
THREAT_NAME_PREFIX[0x61b2] = "Virus:Win2K/"
THREAT_NAME_PREFIX[0x61b5] = "Constructor:Java/"
THREAT_NAME_PREFIX[0x61c8] = "TrojanSpy:WinNT/"
THREAT_NAME_PREFIX[0x61c9] = "TrojanSpy:Java/"
THREAT_NAME_PREFIX[0x61cc] = "VirTool:WinNT/"
THREAT_NAME_PREFIX[0x61cd] = "VirTool:Java/"
THREAT_NAME_PREFIX[0x61d0] = "Exploit:WinNT/"
THREAT_NAME_PREFIX[0x61d1] = "Exploit:Java/"
THREAT_NAME_PREFIX[0x61d8] = "HackTool:WinNT/"
THREAT_NAME_PREFIX[0x61d9] = "HackTool:Java/"
THREAT_NAME_PREFIX[0x61dd] = "TrojanProxy:Java/"
THREAT_NAME_PREFIX[0x6384] = "Backdoor:WinNT/"
THREAT_NAME_PREFIX[0x63ac] = "Trojan:WinNT/"
THREAT_NAME_PREFIX[0x63b2] = "Virus:Win2K/"
THREAT_NAME_PREFIX[0x63cc] = "VirTool:WinNT/"
THREAT_NAME_PREFIX[0x69a5] = "Worm:Java/"
THREAT_NAME_PREFIX[0x69ad] = "Trojan:Java/"
THREAT_NAME_PREFIX[0x7184] = "Backdoor:WinNT/"
THREAT_NAME_PREFIX[0x7190] = "Spammer:WinNT/"
THREAT_NAME_PREFIX[0x71ac] = "Trojan:WinNT/"
THREAT_NAME_PREFIX[0x71ad] = "Trojan:Java/"
THREAT_NAME_PREFIX[0x71cc] = "VirTool:WinNT/"
THREAT_NAME_PREFIX[0x8184] = "Backdoor:DOS/"
THREAT_NAME_PREFIX[0x8185] = "Backdoor:IRC/"
THREAT_NAME_PREFIX[0x8186] = "Backdoor:AutoIt/"
THREAT_NAME_PREFIX[0x8188] = "TrojanDownloader:DOS/"
THREAT_NAME_PREFIX[0x818a] = "TrojanDownloader:AutoIt/"
THREAT_NAME_PREFIX[0x818c] = "TrojanDropper:DOS/"
THREAT_NAME_PREFIX[0x818e] = "TrojanDropper:AutoIt/"
THREAT_NAME_PREFIX[0x8190] = "Spammer:DOS/"
THREAT_NAME_PREFIX[0x8191] = "Spammer:IRC/"
THREAT_NAME_PREFIX[0x8194] = "DDoS:DOS/"
THREAT_NAME_PREFIX[0x8195] = "DDoS:IRC/"
THREAT_NAME_PREFIX[0x8198] = "DoS:DOS/"
THREAT_NAME_PREFIX[0x8199] = "DoS:IRC/"
THREAT_NAME_PREFIX[0x819c] = "Joke:DOS/"
THREAT_NAME_PREFIX[0x81a0] = "PWS:DOS/"
THREAT_NAME_PREFIX[0x81a2] = "PWS:AutoIt/"
THREAT_NAME_PREFIX[0x81a4] = "Worm:DOS/"
THREAT_NAME_PREFIX[0x81a5] = "Worm:IRC/"
THREAT_NAME_PREFIX[0x81a6] = "Worm:AutoIt/"
THREAT_NAME_PREFIX[0x81ac] = "Trojan:DOS/"
THREAT_NAME_PREFIX[0x81ad] = "Trojan:IRC/"
THREAT_NAME_PREFIX[0x81ae] = "Trojan:AutoIt/"
THREAT_NAME_PREFIX[0x81af] = "Trojan:DOS32/"
THREAT_NAME_PREFIX[0x81b0] = "Virus:DOS/"
THREAT_NAME_PREFIX[0x81b2] = "Virus:AutoIt/"
THREAT_NAME_PREFIX[0x81b4] = "Constructor:DOS/"
THREAT_NAME_PREFIX[0x81b5] = "Constructor:IRC/"
THREAT_NAME_PREFIX[0x81c8] = "TrojanSpy:DOS/"
THREAT_NAME_PREFIX[0x81ca] = "TrojanSpy:AutoIt/"
THREAT_NAME_PREFIX[0x81cc] = "VirTool:DOS/"
THREAT_NAME_PREFIX[0x81ce] = "VirTool:AutoIt/"
THREAT_NAME_PREFIX[0x81d0] = "Exploit:DOS/"
THREAT_NAME_PREFIX[0x81d1] = "Exploit:IRC/"
THREAT_NAME_PREFIX[0x81d2] = "Exploit:AutoIt/"
THREAT_NAME_PREFIX[0x81d6] = "TrojanClicker:AutoIt/"
THREAT_NAME_PREFIX[0x81d8] = "HackTool:DOS/"
THREAT_NAME_PREFIX[0x81d9] = "HackTool:IRC/"
THREAT_NAME_PREFIX[0x81da] = "HackTool:AutoIt/"
THREAT_NAME_PREFIX[0x81de] = "TrojanProxy:AutoIt/"
THREAT_NAME_PREFIX[0x8385] = "Backdoor:IRC/"
THREAT_NAME_PREFIX[0x83a4] = "Worm:DOS/"
THREAT_NAME_PREFIX[0x83ac] = "Trojan:DOS/"
THREAT_NAME_PREFIX[0x83ad] = "Trojan:IRC/"
THREAT_NAME_PREFIX[0x83b0] = "Virus:DOS/"
THREAT_NAME_PREFIX[0x85a4] = "Worm:DOS/"
THREAT_NAME_PREFIX[0x85b0] = "Virus:DOS/"
THREAT_NAME_PREFIX[0x87ac] = "Trojan:DOS/"
THREAT_NAME_PREFIX[0x87b0] = "Virus:DOS/"
THREAT_NAME_PREFIX[0x89a4] = "Worm:DOS/"
THREAT_NAME_PREFIX[0x8ba5] = "Worm:IRC/"
THREAT_NAME_PREFIX[0x8bb0] = "Virus:DOS/"
THREAT_NAME_PREFIX[0x9185] = "Backdoor:IRC/"
THREAT_NAME_PREFIX[0x91a4] = "Worm:DOS/"
THREAT_NAME_PREFIX[0x91ad] = "Trojan:IRC/"
THREAT_NAME_PREFIX[0x91b0] = "Virus:DOS/"
THREAT_NAME_PREFIX[0x9b85] = "Backdoor:IRC/"
THREAT_NAME_PREFIX[0xa184] = "Backdoor:Linux/"
THREAT_NAME_PREFIX[0xa186] = "Backdoor:WinCE/"
THREAT_NAME_PREFIX[0xa187] = "Backdoor:MacOS_X/"
THREAT_NAME_PREFIX[0xa188] = "TrojanDownloader:Linux/"
THREAT_NAME_PREFIX[0xa189] = "TrojanDownloader:W97M/"
THREAT_NAME_PREFIX[0xa18a] = "TrojanDownloader:WinCE/"
THREAT_NAME_PREFIX[0xa18b] = "TrojanDownloader:MacOS_X/"
THREAT_NAME_PREFIX[0xa18c] = "TrojanDropper:Linux/"
THREAT_NAME_PREFIX[0xa18d] = "TrojanDropper:W97M/"
THREAT_NAME_PREFIX[0xa18f] = "TrojanDropper:MacOS_X/"
THREAT_NAME_PREFIX[0xa190] = "Spammer:Linux/"
THREAT_NAME_PREFIX[0xa193] = "Spammer:MacOS_X/"
THREAT_NAME_PREFIX[0xa194] = "DDoS:Linux/"
THREAT_NAME_PREFIX[0xa197] = "DDoS:MacOS_X/"
THREAT_NAME_PREFIX[0xa198] = "DoS:Linux/"
THREAT_NAME_PREFIX[0xa19b] = "DoS:MacOS_X/"
THREAT_NAME_PREFIX[0xa19c] = "Joke:Linux/"
THREAT_NAME_PREFIX[0xa1a0] = "PWS:Linux/"
THREAT_NAME_PREFIX[0xa1a1] = "PWS:W97M/"
THREAT_NAME_PREFIX[0xa1a3] = "PWS:MacOS_X/"
THREAT_NAME_PREFIX[0xa1a4] = "Worm:Linux/"
THREAT_NAME_PREFIX[0xa1a6] = "Worm:WinCE/"
THREAT_NAME_PREFIX[0xa1a7] = "Worm:MacOS_X/"
THREAT_NAME_PREFIX[0xa1a8] = "Flooder:Linux/"
THREAT_NAME_PREFIX[0xa1ac] = "Trojan:Linux/"
THREAT_NAME_PREFIX[0xa1ad] = "Trojan:W97M/"
THREAT_NAME_PREFIX[0xa1ae] = "Trojan:WinCE/"
THREAT_NAME_PREFIX[0xa1af] = "Trojan:MacOS_X/"
THREAT_NAME_PREFIX[0xa1b0] = "Virus:Linux/"
THREAT_NAME_PREFIX[0xa1b1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xa1b2] = "Virus:WinCE/"
THREAT_NAME_PREFIX[0xa1b3] = "Virus:MacOS_X/"
THREAT_NAME_PREFIX[0xa1b4] = "Constructor:Linux/"
THREAT_NAME_PREFIX[0xa1b5] = "Constructor:W97M/"
THREAT_NAME_PREFIX[0xa1b8] = "Nuker:Linux/"
THREAT_NAME_PREFIX[0xa1bc] = "Spoofer:Linux/"
THREAT_NAME_PREFIX[0xa1c8] = "TrojanSpy:Linux/"
THREAT_NAME_PREFIX[0xa1cb] = "TrojanSpy:MacOS_X/"
THREAT_NAME_PREFIX[0xa1cc] = "VirTool:Linux/"
THREAT_NAME_PREFIX[0xa1cf] = "VirTool:MacOS_X/"
THREAT_NAME_PREFIX[0xa1d0] = "Exploit:Linux/"
THREAT_NAME_PREFIX[0xa1d1] = "Exploit:W97M/"
THREAT_NAME_PREFIX[0xa1d3] = "Exploit:MacOS_X/"
THREAT_NAME_PREFIX[0xa1d4] = "TrojanClicker:Linux/"
THREAT_NAME_PREFIX[0xa1d8] = "HackTool:Linux/"
THREAT_NAME_PREFIX[0xa1d9] = "HackTool:W97M/"
THREAT_NAME_PREFIX[0xa1db] = "HackTool:MacOS_X/"
THREAT_NAME_PREFIX[0xa1dc] = "TrojanProxy:Linux/"
THREAT_NAME_PREFIX[0xa1e8] = "TrojanNotifier:Linux/"
THREAT_NAME_PREFIX[0xa3ac] = "Trojan:Linux/"
THREAT_NAME_PREFIX[0xa3b0] = "Virus:Linux/"
THREAT_NAME_PREFIX[0xa3b1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xa3b2] = "Virus:WinCE/"
THREAT_NAME_PREFIX[0xa5b1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xa7b1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xa9b1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xabb1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xad84] = "Backdoor:Linux/"
THREAT_NAME_PREFIX[0xb1b0] = "Virus:Linux/"
THREAT_NAME_PREFIX[0xb1b1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xb1d0] = "Exploit:Linux/"
THREAT_NAME_PREFIX[0xb1d8] = "HackTool:Linux/"
THREAT_NAME_PREFIX[0xb9b1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xbbb1] = "Virus:W97M/"
THREAT_NAME_PREFIX[0xc184] = "Backdoor:Win16/"
THREAT_NAME_PREFIX[0xc185] = "Backdoor:X97M/"
THREAT_NAME_PREFIX[0xc189] = "TrojanDownloader:X97M/"
THREAT_NAME_PREFIX[0xc18a] = "TrojanDownloader:SymbOS/"
THREAT_NAME_PREFIX[0xc18c] = "TrojanDropper:Win16/"
THREAT_NAME_PREFIX[0xc18d] = "TrojanDropper:X97M/"
THREAT_NAME_PREFIX[0xc18e] = "TrojanDropper:SymbOS/"
THREAT_NAME_PREFIX[0xc190] = "Spammer:Win16/"
THREAT_NAME_PREFIX[0xc194] = "DDoS:Win16/"
THREAT_NAME_PREFIX[0xc198] = "DoS:Win16/"
THREAT_NAME_PREFIX[0xc19c] = "Joke:Win16/"
THREAT_NAME_PREFIX[0xc1a0] = "PWS:Win16/"
THREAT_NAME_PREFIX[0xc1a1] = "PWS:X97M/"
THREAT_NAME_PREFIX[0xc1a4] = "Worm:Win16/"
THREAT_NAME_PREFIX[0xc1a5] = "Worm:X97M/"
THREAT_NAME_PREFIX[0xc1a6] = "Worm:SymbOS/"
THREAT_NAME_PREFIX[0xc1ac] = "Trojan:Win16/"
THREAT_NAME_PREFIX[0xc1ad] = "Trojan:X97M/"
THREAT_NAME_PREFIX[0xc1ae] = "Trojan:SymbOS/"
THREAT_NAME_PREFIX[0xc1af] = "Trojan:AppleScript/"
THREAT_NAME_PREFIX[0xc1b0] = "Virus:Win16/"
THREAT_NAME_PREFIX[0xc1b1] = "Virus:X97M/"
THREAT_NAME_PREFIX[0xc1b4] = "Constructor:Win16/"
THREAT_NAME_PREFIX[0xc1b8] = "Nuker:Win16/"
THREAT_NAME_PREFIX[0xc1c8] = "TrojanSpy:Win16/"
THREAT_NAME_PREFIX[0xc1c9] = "TrojanSpy:X97M/"
THREAT_NAME_PREFIX[0xc1ca] = "TrojanSpy:SymbOS/"
THREAT_NAME_PREFIX[0xc1cd] = "VirTool:X97M/"
THREAT_NAME_PREFIX[0xc1d1] = "Exploit:X97M/"
THREAT_NAME_PREFIX[0xc1d8] = "HackTool:Win16/"
THREAT_NAME_PREFIX[0xc3ac] = "Trojan:Win16/"
THREAT_NAME_PREFIX[0xc3b1] = "Virus:X97M/"
THREAT_NAME_PREFIX[0xc5b1] = "Virus:X97M/"
THREAT_NAME_PREFIX[0xc7b1] = "Virus:X97M/"
THREAT_NAME_PREFIX[0xc9a4] = "Worm:Win16/"
THREAT_NAME_PREFIX[0xc9af] = "Trojan:AppleScript/"
THREAT_NAME_PREFIX[0xc9b1] = "Virus:X97M/"
THREAT_NAME_PREFIX[0xcbb0] = "Virus:Win16/"
THREAT_NAME_PREFIX[0xcbb1] = "Virus:X97M/"
THREAT_NAME_PREFIX[0xd1b0] = "Virus:Win16/"
THREAT_NAME_PREFIX[0xe184] = "Backdoor:MacOS/"
THREAT_NAME_PREFIX[0xe188] = "TrojanDownloader:MacOS/"
THREAT_NAME_PREFIX[0xe18c] = "TrojanDropper:MacOS/"
THREAT_NAME_PREFIX[0xe18e] = "TrojanDropper:WinHLP/"
THREAT_NAME_PREFIX[0xe190] = "Spammer:MacOS/"
THREAT_NAME_PREFIX[0xe194] = "DDoS:MacOS/"
THREAT_NAME_PREFIX[0xe198] = "DoS:MacOS/"
THREAT_NAME_PREFIX[0xe19c] = "Joke:MacOS/"
THREAT_NAME_PREFIX[0xe1a0] = "PWS:MacOS/"
THREAT_NAME_PREFIX[0xe1a4] = "Worm:MacOS/"
THREAT_NAME_PREFIX[0xe1a8] = "Flooder:MacOS/"
THREAT_NAME_PREFIX[0xe1ac] = "Trojan:MacOS/"
THREAT_NAME_PREFIX[0xe1ad] = "Trojan:PP97M/"
THREAT_NAME_PREFIX[0xe1ae] = "Trojan:WinHLP/"
THREAT_NAME_PREFIX[0xe1b0] = "Virus:MacOS/"
THREAT_NAME_PREFIX[0xe1b1] = "Virus:PP97M/"
THREAT_NAME_PREFIX[0xe1b2] = "Virus:WinHLP/"
THREAT_NAME_PREFIX[0xe1b4] = "Constructor:MacOS/"
THREAT_NAME_PREFIX[0xe1b5] = "Constructor:PP97M/"
THREAT_NAME_PREFIX[0xe1b8] = "Nuker:MacOS/"
THREAT_NAME_PREFIX[0xe1bc] = "Spoofer:MacOS/"
THREAT_NAME_PREFIX[0xe1c8] = "TrojanSpy:MacOS/"
THREAT_NAME_PREFIX[0xe1cc] = "VirTool:MacOS/"
THREAT_NAME_PREFIX[0xe1d0] = "Exploit:MacOS/"
THREAT_NAME_PREFIX[0xe1d4] = "TrojanClicker:MacOS/"
THREAT_NAME_PREFIX[0xe1d8] = "HackTool:MacOS/"
THREAT_NAME_PREFIX[0xe1dc] = "TrojanProxy:MacOS/"
THREAT_NAME_PREFIX[0xe1e8] = "TrojanNotifier:MacOS/"
THREAT_NAME_PREFIX[0xe3b2] = "Virus:WinHLP/"
THREAT_NAME_PREFIX[0xe5b1] = "Virus:PP97M/"
THREAT_NAME_PREFIX[0xe9b0] = "Virus:MacOS/"
THREAT_NAME_PREFIX[0xebb1] = "Virus:PP97M/"