from collections import defaultdict

SIG_TYPES = defaultdict(lambda: "SIGNATURE_TYPE_UNKNOWN")
SIG_TYPES[0x01]= "SIGNATURE_TYPE_RESERVED"
SIG_TYPES[0x02]= "SIGNATURE_TYPE_VOLATILE_THREAT_INFO"
SIG_TYPES[0x03]= "SIGNATURE_TYPE_VOLATILE_THREAT_ID"
SIG_TYPES[0x11]= "SIGNATURE_TYPE_CKOLDREC"
SIG_TYPES[0x20]= "SIGNATURE_TYPE_KVIR32"
SIG_TYPES[0x21]= "SIGNATURE_TYPE_POLYVIR32"
SIG_TYPES[0x27]= "SIGNATURE_TYPE_NSCRIPT_NORMAL"
SIG_TYPES[0x28]= "SIGNATURE_TYPE_NSCRIPT_SP"
SIG_TYPES[0x29]= "SIGNATURE_TYPE_NSCRIPT_BRUTE"
SIG_TYPES[0x2C]= "SIGNATURE_TYPE_NSCRIPT_CURE"
SIG_TYPES[0x30]= "SIGNATURE_TYPE_TITANFLT"
SIG_TYPES[0x3D]= "SIGNATURE_TYPE_PEFILE_CURE"
SIG_TYPES[0x3E]= "SIGNATURE_TYPE_MAC_CURE"
SIG_TYPES[0x40]= "SIGNATURE_TYPE_SIGTREE"
SIG_TYPES[0x41]= "SIGNATURE_TYPE_SIGTREE_EXT"
SIG_TYPES[0x42]= "SIGNATURE_TYPE_MACRO_PCODE"
SIG_TYPES[0x43]= "SIGNATURE_TYPE_MACRO_SOURCE"
SIG_TYPES[0x44]= "SIGNATURE_TYPE_BOOT"
SIG_TYPES[0x49]= "SIGNATURE_TYPE_CLEANSCRIPT"
SIG_TYPES[0x4A]= "SIGNATURE_TYPE_TARGET_SCRIPT"
SIG_TYPES[0x50]= "SIGNATURE_TYPE_CKSIMPLEREC"
SIG_TYPES[0x51]= "SIGNATURE_TYPE_PATTMATCH"
SIG_TYPES[0x53]= "SIGNATURE_TYPE_RPFROUTINE"
SIG_TYPES[0x55]= "SIGNATURE_TYPE_NID"
SIG_TYPES[0x56]= "SIGNATURE_TYPE_GENSFX"
SIG_TYPES[0x57]= "SIGNATURE_TYPE_UNPLIB"
SIG_TYPES[0x58]= "SIGNATURE_TYPE_DEFAULTS"
SIG_TYPES[0x5B]= "SIGNATURE_TYPE_DBVAR"
SIG_TYPES[0x5C]= "SIGNATURE_TYPE_THREAT_BEGIN"
SIG_TYPES[0x5D]= "SIGNATURE_TYPE_THREAT_END"
SIG_TYPES[0x5E]= "SIGNATURE_TYPE_FILENAME"
SIG_TYPES[0x5F]= "SIGNATURE_TYPE_FILEPATH"
SIG_TYPES[0x60]= "SIGNATURE_TYPE_FOLDERNAME"
SIG_TYPES[0x61]= "SIGNATURE_TYPE_PEHSTR"
SIG_TYPES[0x62]= "SIGNATURE_TYPE_LOCALHASH"
SIG_TYPES[0x63]= "SIGNATURE_TYPE_REGKEY"
SIG_TYPES[0x64]= "SIGNATURE_TYPE_HOSTSENTRY"
SIG_TYPES[0x67]= "SIGNATURE_TYPE_STATIC"
SIG_TYPES[0x69]= "SIGNATURE_TYPE_LATENT_THREAT"
SIG_TYPES[0x6A]= "SIGNATURE_TYPE_REMOVAL_POLICY"
SIG_TYPES[0x6B]= "SIGNATURE_TYPE_WVT_EXCEPTION"
SIG_TYPES[0x6C]= "SIGNATURE_TYPE_REVOKED_CERTIFICATE"
SIG_TYPES[0x70]= "SIGNATURE_TYPE_TRUSTED_PUBLISHER"
SIG_TYPES[0x71]= "SIGNATURE_TYPE_ASEP_FILEPATH"
SIG_TYPES[0x73]= "SIGNATURE_TYPE_DELTA_BLOB"
SIG_TYPES[0x74]= "SIGNATURE_TYPE_DELTA_BLOB_RECINFO"
SIG_TYPES[0x75]= "SIGNATURE_TYPE_ASEP_FOLDERNAME"
SIG_TYPES[0x77]= "SIGNATURE_TYPE_PATTMATCH_V2"
SIG_TYPES[0x78]= "SIGNATURE_TYPE_PEHSTR_EXT"
SIG_TYPES[0x79]= "SIGNATURE_TYPE_VDLL_X86"
SIG_TYPES[0x7A]= "SIGNATURE_TYPE_VERSIONCHECK"
SIG_TYPES[0x7B]= "SIGNATURE_TYPE_SAMPLE_REQUEST"
SIG_TYPES[0x7C]= "SIGNATURE_TYPE_VDLL_X64"
SIG_TYPES[0x7E]= "SIGNATURE_TYPE_SNID"
SIG_TYPES[0x7F]= "SIGNATURE_TYPE_FOP"
SIG_TYPES[0x80]= "SIGNATURE_TYPE_KCRCE"
SIG_TYPES[0x83]= "SIGNATURE_TYPE_VFILE"
SIG_TYPES[0x84]= "SIGNATURE_TYPE_SIGFLAGS"
SIG_TYPES[0x85]= "SIGNATURE_TYPE_PEHSTR_EXT2"
SIG_TYPES[0x86]= "SIGNATURE_TYPE_PEMAIN_LOCATOR"
SIG_TYPES[0x87]= "SIGNATURE_TYPE_PESTATIC"
SIG_TYPES[0x88]= "SIGNATURE_TYPE_UFSP_DISABLE"
SIG_TYPES[0x89]= "SIGNATURE_TYPE_FOPEX"
SIG_TYPES[0x8A]= "SIGNATURE_TYPE_PEPCODE"
SIG_TYPES[0x8B]= "SIGNATURE_TYPE_IL_PATTERN"
SIG_TYPES[0x8C]= "SIGNATURE_TYPE_ELFHSTR_EXT"
SIG_TYPES[0x8D]= "SIGNATURE_TYPE_MACHOHSTR_EXT"
SIG_TYPES[0x8E]= "SIGNATURE_TYPE_DOSHSTR_EXT"
SIG_TYPES[0x8F]= "SIGNATURE_TYPE_MACROHSTR_EXT"
SIG_TYPES[0x90]= "SIGNATURE_TYPE_TARGET_SCRIPT_PCODE"
SIG_TYPES[0x91]= "SIGNATURE_TYPE_VDLL_IA64"
SIG_TYPES[0x95]= "SIGNATURE_TYPE_PEBMPAT"
SIG_TYPES[0x96]= "SIGNATURE_TYPE_AAGGREGATOR"
SIG_TYPES[0x97]= "SIGNATURE_TYPE_SAMPLE_REQUEST_BY_NAME"
SIG_TYPES[0x98]= "SIGNATURE_TYPE_REMOVAL_POLICY_BY_NAME"
SIG_TYPES[0x99]= "SIGNATURE_TYPE_TUNNEL_X86"
SIG_TYPES[0x9A]= "SIGNATURE_TYPE_TUNNEL_X64"
SIG_TYPES[0x9B]= "SIGNATURE_TYPE_TUNNEL_IA64"
SIG_TYPES[0x9C]= "SIGNATURE_TYPE_VDLL_ARM"
SIG_TYPES[0x9D]= "SIGNATURE_TYPE_THREAD_X86"
SIG_TYPES[0x9E]= "SIGNATURE_TYPE_THREAD_X64"
SIG_TYPES[0x9F]= "SIGNATURE_TYPE_THREAD_IA64"
SIG_TYPES[0xA0]= "SIGNATURE_TYPE_FRIENDLYFILE_SHA256"
SIG_TYPES[0xA1]= "SIGNATURE_TYPE_FRIENDLYFILE_SHA512"
SIG_TYPES[0xA2]= "SIGNATURE_TYPE_SHARED_THREAT"
SIG_TYPES[0xA3]= "SIGNATURE_TYPE_VDM_METADATA"
SIG_TYPES[0xA4]= "SIGNATURE_TYPE_VSTORE"
SIG_TYPES[0xA5]= "SIGNATURE_TYPE_VDLL_SYMINFO"
SIG_TYPES[0xA6]= "SIGNATURE_TYPE_IL2_PATTERN"
SIG_TYPES[0xA7]= "SIGNATURE_TYPE_BM_STATIC"
SIG_TYPES[0xA8]= "SIGNATURE_TYPE_BM_INFO"
SIG_TYPES[0xA9]= "SIGNATURE_TYPE_NDAT"
SIG_TYPES[0xAA]= "SIGNATURE_TYPE_FASTPATH_DATA"
SIG_TYPES[0xAB]= "SIGNATURE_TYPE_FASTPATH_SDN"
SIG_TYPES[0xAC]= "SIGNATURE_TYPE_DATABASE_CERT"
SIG_TYPES[0xAD]= "SIGNATURE_TYPE_SOURCE_INFO"
SIG_TYPES[0xAE]= "SIGNATURE_TYPE_HIDDEN_FILE"
SIG_TYPES[0xAF]= "SIGNATURE_TYPE_COMMON_CODE"
SIG_TYPES[0xB0]= "SIGNATURE_TYPE_VREG"
SIG_TYPES[0xB1]= "SIGNATURE_TYPE_NISBLOB"
SIG_TYPES[0xB2]= "SIGNATURE_TYPE_VFILEEX"
SIG_TYPES[0xB3]= "SIGNATURE_TYPE_SIGTREE_BM"
SIG_TYPES[0xB4]= "SIGNATURE_TYPE_VBFOP"
SIG_TYPES[0xB5]= "SIGNATURE_TYPE_VDLL_META"
SIG_TYPES[0xB6]= "SIGNATURE_TYPE_TUNNEL_ARM"
SIG_TYPES[0xB7]= "SIGNATURE_TYPE_THREAD_ARM"
SIG_TYPES[0xB8]= "SIGNATURE_TYPE_PCODEVALIDATOR"
SIG_TYPES[0xBA]= "SIGNATURE_TYPE_MSILFOP"
SIG_TYPES[0xBB]= "SIGNATURE_TYPE_KPAT"
SIG_TYPES[0xBC]= "SIGNATURE_TYPE_KPATEX"
SIG_TYPES[0xBD]= "SIGNATURE_TYPE_LUASTANDALONE"
SIG_TYPES[0xBE]= "SIGNATURE_TYPE_DEXHSTR_EXT"
SIG_TYPES[0xBF]= "SIGNATURE_TYPE_JAVAHSTR_EXT"
SIG_TYPES[0xC0]= "SIGNATURE_TYPE_MAGICCODE"
SIG_TYPES[0xC1]= "SIGNATURE_TYPE_CLEANSTORE_RULE"
SIG_TYPES[0xC2]= "SIGNATURE_TYPE_VDLL_CHECKSUM"
SIG_TYPES[0xC3]= "SIGNATURE_TYPE_THREAT_UPDATE_STATUS"
SIG_TYPES[0xC4]= "SIGNATURE_TYPE_VDLL_MSIL"
SIG_TYPES[0xC5]= "SIGNATURE_TYPE_ARHSTR_EXT"
SIG_TYPES[0xC6]= "SIGNATURE_TYPE_MSILFOPEX"
SIG_TYPES[0xC7]= "SIGNATURE_TYPE_VBFOPEX"
SIG_TYPES[0xC8]= "SIGNATURE_TYPE_FOP64"
SIG_TYPES[0xC9]= "SIGNATURE_TYPE_FOPEX64"
SIG_TYPES[0xCA]= "SIGNATURE_TYPE_JSINIT"
SIG_TYPES[0xCB]= "SIGNATURE_TYPE_PESTATICEX"
SIG_TYPES[0xCC]= "SIGNATURE_TYPE_KCRCEX"
SIG_TYPES[0xCD]= "SIGNATURE_TYPE_FTRIE_POS"
SIG_TYPES[0xCE]= "SIGNATURE_TYPE_NID64"
SIG_TYPES[0xCF]= "SIGNATURE_TYPE_MACRO_PCODE64"
SIG_TYPES[0xD0]= "SIGNATURE_TYPE_BRUTE"
SIG_TYPES[0xD1]= "SIGNATURE_TYPE_SWFHSTR_EXT"
SIG_TYPES[0xD2]= "SIGNATURE_TYPE_REWSIGS"
SIG_TYPES[0xD3]= "SIGNATURE_TYPE_AUTOITHSTR_EXT"
SIG_TYPES[0xD4]= "SIGNATURE_TYPE_INNOHSTR_EXT"
SIG_TYPES[0xD5]= "SIGNATURE_TYPE_ROOTCERTSTORE"
SIG_TYPES[0xD6]= "SIGNATURE_TYPE_EXPLICITRESOURCE"
SIG_TYPES[0xD7]= "SIGNATURE_TYPE_CMDHSTR_EXT"
SIG_TYPES[0xD8]= "SIGNATURE_TYPE_FASTPATH_TDN"
SIG_TYPES[0xD9]= "SIGNATURE_TYPE_EXPLICITRESOURCEHASH"
SIG_TYPES[0xDA]= "SIGNATURE_TYPE_FASTPATH_SDN_EX"
SIG_TYPES[0xDB]= "SIGNATURE_TYPE_BLOOM_FILTER"
SIG_TYPES[0xDC]= "SIGNATURE_TYPE_RESEARCH_TAG"
SIG_TYPES[0xDE]= "SIGNATURE_TYPE_ENVELOPE"
SIG_TYPES[0xDF]= "SIGNATURE_TYPE_REMOVAL_POLICY64"
SIG_TYPES[0xE0]= "SIGNATURE_TYPE_REMOVAL_POLICY64_BY_NAME"
SIG_TYPES[0xE1]= "SIGNATURE_TYPE_VDLL_META_X64"
SIG_TYPES[0xE2]= "SIGNATURE_TYPE_VDLL_META_ARM"
SIG_TYPES[0xE3]= "SIGNATURE_TYPE_VDLL_META_MSIL"
SIG_TYPES[0xE4]= "SIGNATURE_TYPE_MDBHSTR_EXT"
SIG_TYPES[0xE5]= "SIGNATURE_TYPE_SNIDEX"
SIG_TYPES[0xE6]= "SIGNATURE_TYPE_SNIDEX2"
SIG_TYPES[0xE7]= "SIGNATURE_TYPE_AAGGREGATOREX"
SIG_TYPES[0xE8]= "SIGNATURE_TYPE_PUA_APPMAP"
SIG_TYPES[0xE9]= "SIGNATURE_TYPE_PROPERTY_BAG"
SIG_TYPES[0xEA]= "SIGNATURE_TYPE_DMGHSTR_EXT"
SIG_TYPES[0xEB]= "SIGNATURE_TYPE_DATABASE_CATALOG"